/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLOptionElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLOptionElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLOptionElement.h"
#include "gdom/PrivateIntGdomHTMLOptionElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLOptionElement::GDOMHTMLOptionElement(PassRefPtr<WebCore::HTMLOptionElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLOptionElement.h"
#include <gdom/GdomHTMLOptionElement.h>
#include <gdom/PrivateGdomHTMLOptionElement.h>
#include <gdom/PrivateIntGdomHTMLOptionElement.h>
#include <gdom/GdomHTMLOptionElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLOptionElement, gdom_html_option_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLOptionElementPrivate {
    class WebCore::HTMLOptionElement *item;
};

#define GDOM_HTML_OPTION_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_OPTION_ELEMENT, GdomHTMLOptionElementPrivate))
*/
G_END_DECLS
WebCore::HTMLOptionElement *
gdom_html_option_element_get_private(GdomHTMLOptionElement *request)
{
    GDOMHTMLOptionElement *res;
    res = static_cast<GDOMHTMLOptionElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLOptionElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_FORM,
    PROP_DEFAULT_SELECTED,
    PROP_TEXT,
    PROP_INDEX,
    PROP_DISABLED,
    PROP_LABEL,
    PROP_SELECTED,
    PROP_VALUE,
};


static void gdom_html_option_element_finalize(GObject* object)
{
    /*GdomHTMLOptionElement* request = GDOM_HTML_OPTION_ELEMENT(object);*/
    /*GdomHTMLOptionElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_option_element_parent_class)->finalize(object);
}

static void gdom_html_option_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLOptionElement *self = GDOM_HTML_OPTION_ELEMENT(object);
    WebCore::HTMLOptionElement * gself = (gdom_html_option_element_get_private(self));
    switch (prop_id) {
     case PROP_DEFAULT_SELECTED:
    {
         gself->setDefaultSelected((g_value_get_boolean (value)) );
         break;
    }
     case PROP_TEXT:
    {
         WebCore::ExceptionCode ec = 0;
         gself->setText(WebCore::String::fromUTF8(g_value_get_string (value)) , ec );
         break;
    }
     case PROP_DISABLED:
    {
         gself->setDisabled((g_value_get_boolean (value)) );
         break;
    }
     case PROP_LABEL:
    {
         gself->setLabel(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_SELECTED:
    {
         gself->setSelected((g_value_get_boolean (value)) );
         break;
    }
     case PROP_VALUE:
    {
         gself->setValue(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_option_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLOptionElement *self = GDOM_HTML_OPTION_ELEMENT(object);
    WebCore::HTMLOptionElement * gself = (gdom_html_option_element_get_private(self));
    switch (prop_id) {
    case PROP_FORM:
    {
         PassRefPtr<WebCore::HTMLFormElement> ptr = gself->form();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_DEFAULT_SELECTED:
    {
         g_value_set_boolean (value, gself->defaultSelected());
         break;
    }
    case PROP_TEXT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->text()));
         break;
    }
    case PROP_INDEX:
    {
         g_value_set_long (value, gself->index());
         break;
    }
    case PROP_DISABLED:
    {
         g_value_set_boolean (value, gself->disabled());
         break;
    }
    case PROP_LABEL:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->label()));
         break;
    }
    case PROP_SELECTED:
    {
         g_value_set_boolean (value, gself->selected());
         break;
    }
    case PROP_VALUE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->value()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_option_element_class_init(GdomHTMLOptionElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_option_element_finalize;
    g_klass->set_property = gdom_html_option_element__set_property_fn;
    g_klass->get_property = gdom_html_option_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_FORM,
            g_param_spec_object ("form", /* name */
                "html_option_element_form", /* short description */
                "read-only  GdomHTMLFormElement * HTMLOptionElement.form", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_FORM_ELEMENT, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_DEFAULT_SELECTED,
            g_param_spec_boolean ("default_selected", /* name */
                "html_option_element_default_selected", /* short description */
                "read-write  gboolean HTMLOptionElement.default_selected", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TEXT,
            g_param_spec_string ("text", /* name */
                "html_option_element_text", /* short description */
                "read-write  gchar * HTMLOptionElement.text", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_INDEX,
            g_param_spec_long ("index", /* name */
                "html_option_element_index", /* short description */
                "read-only  glong HTMLOptionElement.index", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_DISABLED,
            g_param_spec_boolean ("disabled", /* name */
                "html_option_element_disabled", /* short description */
                "read-write  gboolean HTMLOptionElement.disabled", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_LABEL,
            g_param_spec_string ("label", /* name */
                "html_option_element_label", /* short description */
                "read-write  gchar * HTMLOptionElement.label", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SELECTED,
            g_param_spec_boolean ("selected", /* name */
                "html_option_element_selected", /* short description */
                "read-write  gboolean HTMLOptionElement.selected", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_VALUE,
            g_param_spec_string ("value", /* name */
                "html_option_element_value", /* short description */
                "read-write  gchar * HTMLOptionElement.value", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLOptionElementPrivate));*/
}

static void gdom_html_option_element_init(GdomHTMLOptionElement* request)
{
    /*GdomHTMLOptionElementPrivate* priv = GDOM_HTML_OPTION_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

